# Molecules

In the field of cryo-ET, proper operations on molecules are essential to get a good
result. In this section, you'll learn how to filter, split, combine, transform and
analyze molecules.

- [Spline to Molecules](spline_to_molecules.md)
- [Molecule Features](features.md)
- [Expressions](expressions.md)
- [Filter molecules](filter_molecules.md)
- [Split & Combine](split_and_combine.md)
- [Transform Molecules](transform.md)
- [Feature Names](headers.md)
